@@ -2,16 +2,24 @@
 """
 @Author  : zh_o
 """
-from typing import Tuple, List, Text, Set, Union
+import os.path
+import sys
+import time
+import uuid
+from typing import Tuple, List, Text, Callable
+
 import allure
-from selenium.webdriver.common.by import By
+from selenium.common.exceptions import WebDriverException, NoSuchElementException
 from selenium.webdriver import ActionChains
+from selenium.webdriver.common.by import By
 from selenium.webdriver.remote.switch_to import SwitchTo
-from selenium.webdriver.support.wait import WebDriverWait
 from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support import expected_conditions as EC
-from melon.webdrivers import driver
+from selenium.webdriver.support.wait import WebDriverWait
+
 from melon.settings import get_config
+from melon.webdrivers import driver
+from melon.loggers import logger
 
 
 class MelonElement(WebElement):
@@ -95,6 +103,21 @@ class BasePage:
         url = f'{base_url}{url}'
         self.__step(f'跳转到 {url}', self.driver.get, url)
 
+    def screenshot(self) -> Text:
+        """截图保存到文件"""
+        screenshot_dir = os.path.abspath(get_config('melon.selenium.screenshot_dir', '.'))
+        screenshot_dir = os.path.join(screenshot_dir, time.strftime("%Y-%m-%d"))
+
+        if not os.path.exists(screenshot_dir):
+            os.mkdir(screenshot_dir)
+
+        file_name = f'{uuid.uuid4()}.png'
+        file_name = os.path.join(screenshot_dir, file_name)
+        png = self.driver.get_screenshot_as_png()
+        with open(file_name, 'wb') as f:
+            f.write(png)
+        return png
+
     def close(self):
         """关闭浏览器"""
         self.__step('关闭浏览器', self.driver.close)
@@ -113,14 +136,15 @@ class BasePage:
             if not _target:
                 return object.__getattribute__(self, attr)
 
-            if isinstance(_target, (List[MelonElement], Tuple[MelonElement], Set[MelonElement])):
+            if isinstance(_target, List) and isinstance(_target[0], MelonElement):
                 # 可迭代属性
                 _proxy = self.__proxy_iterable(_target)
             elif isinstance(_target, MelonElement):
                 # 单属性
                 _proxy = self.__proxy_single(_target)
             else:
-                raise ValueError(f'not supported element [{attr}]')
+                logger.error(f'not supported element [{attr}]')
+                sys.exit(0)
 
             return _proxy
 
@@ -132,22 +156,22 @@ class BasePage:
         """
         timeout = _target.timeout
         if timeout:
-            _proxy = self.find_element_await(_target.locator, timeout)
+            _proxy = self.__handle_exceptions(self.find_element_await, _target.label, locator=_target.locator, timeout=timeout)
         else:
-            _proxy = self.find_element(_target.locator)
+            _proxy = self.__handle_exceptions(self.find_element, _target.label, locator=_target.locator)
         _proxy._label = _target.label
         return _proxy
 
-    def __proxy_iterable(self, _targets: Union[List[MelonElement], Tuple[MelonElement], Set[MelonElement]]) -> List[WebElement]:
+    def __proxy_iterable(self, _targets: List[MelonElement]) -> List[WebElement]:
         """
         代理可迭代属性
         """
         _target = _targets[0]
         timeout = _target.timeout
         if timeout:
-            _proxy = self.find_elements_await(_target.locator, timeout)
+            _proxy = self.__handle_exceptions(self.find_elements_await, _target.label, locator=_target.locator, timeout=timeout)
         else:
-            _proxy = self.find_elements(_target.locator)
+            _proxy = self.__handle_exceptions(self.find_elements, _target.label, locator=_target.locator)
         [setattr(e, '_label', _target.label) for e in _proxy if e]
         return _proxy
 
@@ -157,6 +181,8 @@ class BasePage:
             return tuple()
 
         for target in args:
+            if not target:
+                continue
             # 代理方法
             raw_click = target.click
             raw_send_keys = target.send_keys
@@ -172,3 +198,22 @@ class BasePage:
             target.click = _click
             target.send_keys = _send_keys
         return args
+
+    def __handle_exceptions(self, func: Callable, desc: Text, *args, **kwargs):
+        """异常处理"""
+        result = None
+        try:
+            result = func(*args, **kwargs)
+        except NoSuchElementException as e:
+            png = self.screenshot()
+            allure.attach(png, f'{desc}未找到', allure.attachment_type.PNG)
+            raise e
+        except WebDriverException as e:
+            png = self.screenshot()
+            allure.attach(png, desc, allure.attachment_type.PNG)
+            raise e
+        except Exception as e:
+            png = self.screenshot()
+            allure.attach(png, desc, allure.attachment_type.PNG)
+            logger.error(e)
+        return result
