@@ -4,8 +4,10 @@
 """
 import os
 import importlib
+import sys
 from typing import Dict, Text, Callable
 from types import FunctionType
+from melon.loggers import logger
 
 
 def locate_file(start_path: Text, file_name: Text) -> Text:
@@ -20,7 +22,8 @@ def locate_file(start_path: Text, file_name: Text) -> Text:
     elif os.path.isdir(start_path):
         start_dir_path = start_path
     else:
-        raise Exception(f'invalid path: {start_path}')
+        logger.error(f'invalid path: {start_path}')
+        sys.exit(0)
 
     file_path = os.path.join(start_dir_path, file_name)
     # 定位到目标文件
@@ -29,7 +32,8 @@ def locate_file(start_path: Text, file_name: Text) -> Text:
 
     parent_dir = os.path.dirname(start_dir_path)
     if parent_dir == start_dir_path:
-        raise Exception(f"{file_name} not found in {start_path}")
+        logger.error(f'{file_name} not found in {start_path}')
+        sys.exit(0)
 
     return locate_file(parent_dir, file_name)
 
@@ -59,7 +63,8 @@ def load_application_functions() -> Dict[Text, Callable]:
     try:
         module = importlib.import_module('application')
     except Exception as e:
-        raise ImportError(f'error occurred in application.py [{e.args[0]}]')
+        logger.error(f'error occurred in application.py [{e.args[0]}]')
+        sys.exit(0)
     module = importlib.reload(module)
     return load_module_functions(module)
 
