@@ -57,7 +57,7 @@ class ParameterizeUtil:
         :param path: csv文件路径
         :param headers: 表头(为空则默认取首行为表头)
         """
-        with open(file=path, encoding='utf8') as csv_file:
+        with open(file=path, encoding='UTF-8') as csv_file:
             contents = [ParameterizeUtil.__parse_expression_all(line) for line in csv_file
                         if not line.startswith('#')]
             lines = list(csv.DictReader(contents, fieldnames=headers))
